FilteredResourcesParamBuilder

Struct FilteredResourcesParamBuilder 

pub struct FilteredResourcesParamBuilder<T>(/* private fields */);
๐Ÿ‘ŽDeprecated since 0.20.0:

Use QueryParamBuilder instead.

A SystemParamBuilder for a FilteredResources. See the FilteredResources docs for examples.

Implementations

Source

impl<T> FilteredResourcesParamBuilder<T>

pub fn new(f: T) -> Self
where T: FnOnce(&mut FilteredResourcesBuilder<'_>),

Creates a SystemParamBuilder for a FilteredResources that accepts a callback to configure the FilteredResourcesBuilder.

Source

impl<'a> FilteredResourcesParamBuilder<Box<dyn FnOnce(&mut FilteredResourcesBuilder<'_>) + 'a>>

pub fn new_box(f: impl FnOnce(&mut FilteredResourcesBuilder<'_>) + 'a) -> Self

Creates a SystemParamBuilder for a FilteredResources that accepts a callback to configure the FilteredResourcesBuilder. This boxes the callback so that it has a common type.