IntoPipeSystem

Struct IntoPipeSystem 

pub struct IntoPipeSystem<A, B, N: PipeSystemName = ()> { /* private fields */ }
An IntoSystem creating an instance of PipeSystem.

This struct is created by IntoSystem::pipe(). See its documentation for more.

Implementations

Source

impl<A, B> IntoPipeSystem<A, B>

pub const fn new(a: A, b: B) -> Self

Creates a new IntoSystem that pipes two inner systems.

Unless changed, the name of the system will be set to a combination of the names of the inner systems.

pub fn with_name_fn( self, name: impl FnOnce(DebugName, DebugName) -> DebugName, ) -> IntoPipeSystem<A, B, impl PipeSystemName>

Set the name of the output PipeSystem to the output of a function.

The parameters to the function are the names of the two systems. The first system is the one passed as self to IntoSystem::pipe, and the second system is the one passed as a parameter.

Note that when piping multiple systems, they may themselves be PipeSystems!

pub fn with_name( self, name: impl Into<DebugName>, ) -> IntoPipeSystem<A, B, impl PipeSystemName>

Set the name of the output PipeSystem to the given string.

pub fn with_first_name(self) -> IntoPipeSystem<A, B, impl PipeSystemName>

Set the name of the output PipeSystem to the name of the first system.

Note that the “first” system is the one passed as self to IntoSystem::pipe. When piping multiple systems, that may itself by another PipeSystem!

let system = a.pipe(b).pipe(c).with_first_name();
assert_eq!("Pipe(a, b)", &*IntoSystem::into_system(system).name());
let system = a.pipe(b.pipe(c)).with_first_name();
assert_eq!("a", &*IntoSystem::into_system(system).name());
pub fn with_second_name(self) -> IntoPipeSystem<A, B, impl PipeSystemName>

Set the name of the output PipeSystem to the name of the second system.

Note that the “second” system is the one passed as a parameter to IntoSystem::pipe. When piping multiple systems, that may itself by another PipeSystem!

let system = a.pipe(b).pipe(c).with_second_name();
assert_eq!("c", &*IntoSystem::into_system(system).name());
let system = a.pipe(b.pipe(c)).with_second_name();
assert_eq!("Pipe(b, c)", &*IntoSystem::into_system(system).name());